function setup()

% Author: Ivan E. Cao-Berg (icaoberg@cmu.edu)
% Created: November 24, 2008
%
% Copyright (C) 2008-2012 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% March 14, 2012 I. Cao-Berg Made it sure that .git folder is not added to
%                path just in case they use the git clone
% March 19, 2012 R.F. Murphy Fix addpaths
% March 27, 2012 I. Cao-Berg Turned script into function
% April 11, 2012 R.F. Murphy Support two digit sub- and sub-subversions
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

addpath( pwd );
addpath(genpath( [pwd '/utilities']));
addpath(genpath( [pwd '/models']));
addpath(genpath( [pwd '/demos']));
if ~isCompatible
    rmpath( genpath( pwd ) );
    rmpath(genpath( 'utilities' ));
    error( ['CellOrganizer: The current system is not ' ...
        'compatible with the toolbox']);
end

version = '1.6.0';
versionURL = 'http://murphylab.web.cmu.edu/software/CellOrganizer/version';

try
   fprintf(1,'%s',['Checking for new stable version... ']);
   latestVersion = urlread( versionURL );
   if latestVersion(end) == 10 latestVersion = latestVersion(1:end-1); end

   if upgrade( version, latestVersion )
      fprintf(1,'%s\n',['A newer version (' latestVersion ') is available.']);
   else
      fprintf(1,'%s\n',['Version is up to date.']);
   end
catch
   fprintf(1,'%s\n',['Unable to connect.']);
end
end%setup

function answer = upgrade( version, latestVersion )

version = sscanf(version, '%d.%d.%d')';
if length(version) < 3
   version(3) = 0;
end

latestVersion = sscanf(latestVersion, '%d.%d.%d')';
if length(latestVersion) < 3
   latestVersion(3) = 0;
end

answer = (sign(version - latestVersion) * [10; .1; .001]) < 0;

end%upgrade

