function model = train_cell_shape_model( imgpath )
% Train cell shape model using 3D Hela images

% Author: Tao Peng
%
% Copyright (C) 2011-2012 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% March 23, 2012 I. Cao-Berg Modified save path directory
% March 28, 2012 R.F. Murphy Change to 3D cell/nuclear ratios
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

savepath = [ pwd filesep 'temp' filesep 'cell_shape_eigen'];
if ~exist(savepath,'dir')
    mkdir(savepath)
end

rad_ratio = find_cell_ratios( imgpath, savepath );
rad_ratio(rad_ratio>1) = 1;

[x,y]=find(isinf(rad_ratio));
x=unique(x);
for i=1:1:length(x)
   disp(['Ignoring feature vector ' num2str(i)]);
   rad_ratio = [rad_ratio(1:x-1,:,:); rad_ratio(x+1:end,:,:)];  
end

[x,y]=find(isnan(rad_ratio));
x=unique(x);
for i=1:1:length(x)
   disp(['Ignoring feature vector ' num2str(i)]);
   rad_ratio = [rad_ratio(1:x-1,:,:); rad_ratio(x+1:end,:,:)];  
end

%icaoberg april 2, 2012
[mu,coeff,score,latent] = eff_PCA(rad_ratio);

save([savepath '/pca_result.mat'],'mu','coeff','score','latent')

%% Cell shape model
model = struct('name',[],'meanShape',[],'modeShape',[],'eigens',[]);
model.name = 'RREigen';
model.meanShape = struct('const',mu);

try
    model.modeShape = struct('const',coeff(:,1:20));
    model.eigens = struct('stat',latent(1:20));
catch err
    model.modeShape = struct('const',coeff(:,1:end));
    model.eigens = struct('stat',latent(1:end));
end

save([savepath '/cell_shape_model.mat'],'model')
