function findobjs_run(impath,savepath)
% Extract objects from 3D HeLa images

% Author: Tao Peng
% Edited: Ivan E. Cao-Berg
%
% Copyright (C) 2011 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

celldirlist = ml_dir([impath filesep 'cell*']);
delim = find( impath == filesep );
protype = impath(delim(end)+1:end);
savepath = [savepath filesep protype];

if ~exist(savepath,'dir')
    mkdir(savepath)
end

if ~exist( [savepath filesep 'preprocessed'], 'dir' )
    mkdir( [savepath filesep 'preprocessed'] );
end

H = fspecial3('Gaussian',[10,10,3]);

for i = 1:length(celldirlist)
    disp([protype ' image ' num2str(i)])
    
    if ~exist( [savepath filesep 'obj' num2str(i) '.mat'], 'file' )
        imgdir = [impath filesep celldirlist{i}];
        disp( 'Loading image and resizing image' )
        prot = ml_loadimage([imgdir filesep 'prot'],'tif');
        stacknum = size(prot,3);
        prot = double(prot);
        croplist = ml_dir([imgdir filesep 'crop' filesep '*.tif']);
        crop = [];
        for k = 1:length(croplist)
            crop(:,:,k) = ml_readimage([imgdir filesep 'crop' filesep croplist{k}]) > 0;
        end
        crop = any(crop,3);
        
        disp( 'Preprocessing image' )
        procimage = ml_preprocess(double(prot),crop,'ml','yesbgsub','nih');
        %procimage(1:12,:,:) = [];
        %procimage(end-11:end,:,:) = [];
        %procimage(:,1:12,:) = [];
        %procimage(:,end-11:end,:) = [];
        
        dimobjimg = imfilter(procimage,H,'same');
        centers{i} =  ml_imlocalmax(dimobjimg);
        
        save([savepath filesep 'preprocessed' filesep protype num2str(i) '.mat'], 'procimage', 'prot', 'crop' );
        
        objects = cell(10,10);
        for r = 1:10
            for c = 1:10
                disp( ['Finding objects in block {' num2str(r) ',' num2str(c) '}' ] );
                blockimage = procimage((r-1)*100+1:r*100,(c-1)*100+1:c*100,:);
                objects{r,c} = ml_findobjs(blockimage);
            end
        end
        
        save([savepath filesep 'obj' num2str(i)],'objects','centers')
    else
        disp( 'Intermediate files found, skipping locating objects' );
    end
end
