function model = gmm_objsizefit(protype,datadir)
% Learn object size model for each location pattern

% Author: Tao Peng
% Edited: Ivan E. Cao-Berg
%
% Copyright (C) 2011 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

load([datadir '/Distr_' protype])
objsize = real(objsize);

x = objsize(:,1);
y = objsize(:,2);
z = objsize(:,3);

lambda = expfit(x);
model.x = struct('name','exp','beta',lambda);

% Fit the y-x conditional normal distribution
Y_X = cell(20,1);
for i=1:20
    y_given_x = y(x>i-1&x<=i);
    Y_X{i} = y_given_x;
    if ~isempty(y_given_x)
        [mu(i),sigma(i)] = normfit(y_given_x);
    end
end

x = .5:14.5;
optvars.alpha1 = 6.5;
optvars.alpha2 = 1.4;
u = mu(1:15);
x(u>=optvars.alpha1) = [];
u(u>=optvars.alpha1) = [];
optvars.beta1 = sum(-x.*log(1-u/optvars.alpha1))/sum(x.^2);
u = sigma(1:15);
x = .5:14.5;
x(u>=optvars.alpha2) = [];
u(u>=optvars.alpha2) = [];
optvars.beta2 = sum(-x.*log(1-u/optvars.alpha2))/sum(x.^2);

model.y_x = struct('name','norm',...
                    'a1',optvars.alpha1,...
                    'b1',optvars.beta1,...
                    'a2',optvars.alpha2,...
                    'b2',optvars.beta2);

% Fit the z-x conditional normal distribution
%clear mu sigma
Z_X = cell(20,1);
for i=1:20
    z_given_x = z(x>i-1&x<=i);
    Z_X{i} = z_given_x;
    if ~isempty(z_given_x)
        [mu(i),sigma(i)] = normfit(z_given_x);
    end
end

x = .5:14.5;
optvars.alpha1 = 3.5;
optvars.alpha2 = 1.4;
u = mu(1:15);
x(u>=optvars.alpha1) = [];
u(u>=optvars.alpha1) = [];
optvars.beta1 = sum(-x.*log(1-u/optvars.alpha1))/sum(x.^2);
u = sigma(1:15);
x = .5:14.5;
x(u>=optvars.alpha2) = [];
u(u>=optvars.alpha2) = [];
optvars.beta2 = sum(-x.*log(1-u/optvars.alpha2))/sum(x.^2);

model.z_x = struct('name','norm',...
                    'a1',optvars.alpha1,...
                    'b1',optvars.beta1,...
                    'a2',optvars.alpha2,...
                    'b2',optvars.beta2);
