function learngaussobjs_run2( imgdir, savedir, param )
% Fit gaussian distributions to the objects

% Author: Tao Peng
%
% Copyright (C) 2012 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

delim = find( imgdir == filesep );
protype = imgdir(delim(end)+1:end);

if ~exist('param','var')
    param = struct([]);
end

param = ml_initparam(param, ...
    struct('modelname','vesicle','imageSize',[],'disp',0));
model.name = param.modelname;

if ~isfield(param,'ml_objgaussmix')
    param.ml_objgaussmix = struct([]);
end

param.ml_objgaussmix = ml_initparam(param.ml_objgaussmix, ...
    struct('filter',fspecial3('Gaussian',[10,10,3]),'mindist',5, ...
    'isshow',0,'gmm',struct('covartype','full',...
    'options',[0 1 0 0 0 0 0 0 0 0 0 0 0 1000 1 20])));

if exist( [savedir filesep protype '_gaussobjs.mat'] )
    disp(['Skipping calculation of ' protype ' Gaussian objects, intermediate results found']);
else
    mixes = {};
    temporaryFilesDirectory = ['./temp/protein_objects_gaussian/original_objects/' protype ];
    files = ml_dir([temporaryFilesDirectory filesep 'obj*.mat']);
    
    for i = 1:1:length(files)
        %load(['./temp/protein_objects_gaussian/original_objects/' protype '/obj' num2str(i) '.mat'])
        load([temporaryFilesDirectory filesep files{i}]);
        disp([protype ' image ' num2str(i)])
        
        %learn Gaussian mixture model
        ct = 0;
        for r = 1:10
            for c = 1:10
                blockobjs = objects{r,c};
                if ~isempty(blockobjs)
                    disp(['Block (' int2str(r) ', ' int2str(c) ')'])
                    for j = 1:length(blockobjs)
                        obj = blockobjs{j};
                        
                        if length(obj) > 1
                            try
                                disp( [ 'Object:' num2str(j) ' has size ' num2str(length(obj)) ] );
                                ct = ct + 1;
                                disp( ['Count: ' num2str(ct) ] );
                                if ~exist( [savedir filesep files{i} '_' num2str(i) '_' ...
                                        num2str(r) '_' num2str(c) '_' num2str(j) '.mat'] )
                                    objectintensity = sum(obj(:,end));
                                    objintens{length(mixes)+1}(ct)= objectintensity;
                                    offset = 100*[r-1,c-1,0];
                                    offsets{length(mixes)+1}(ct,:)= offset;
                                    
                                    mix = ml_objgaussmix(obj,...
                                        [],param.ml_objgaussmix);
                                    mixes{length(mixes)+1}(ct) = mix;
                                    %warning('Matrix must be positive definite');
                                    
                                    disp( ['(mixes,objintens,offsets)=' ...
                                        '(' num2str(length(mixes)) ...
                                        ',' num2str(length(objintens)) ....
                                        ',' num2str(length(offsets)) ')' ] );
                                    save([savedir filesep files{i} '_' num2str(i) '_' ...
                                        num2str(r) '_' num2str(c) '_' num2str(j) '.mat'], ...
                                        'mix', 'offset', 'objectintensity' );
                                else
                                    disp('Intermediate results found. Loading from disk.');
                                    load([savedir filesep files{i} '_' num2str(i) '_' ...
                                        num2str(r) '_' num2str(c) '_' num2str(j) '.mat'])
                                    objintens{length(mixes)+1}(ct)= objectintensity;
                                    offsets{length(mixes)+1}(ct,:)= offset;
                                    mixes{length(mixes)+1}(ct) = mix;
                                end
                            catch err
                                disp(['Unable to calculate mixture for object:' num2str(j)]);
                            end
                        end
                    end
                end
            end
        end
    end
    
    save([savedir filesep protype '_gaussobjs'], ...
        'mixes','objintens','offsets')
end
end
