function BETA = objpos_run(protype,impath,savepath )
% Learn the protein object position model

impath = [impath '/' protype];
celldirlist = ml_dir([impath '/cell*']);
if ~exist(savepath,'dir')
    mkdir(savepath)
end

datapath = './inter_results/protein_objects_gaussian/object_gaussians';
gaussobjpath = [datapath '/' protype];

if ~exist( [savepath filesep protype '_beta_all.mat'] )
    X = [];
    Y = [];
    
    imageID = [];
    for i = 1:1:length(celldirlist)
        disp([protype 'image ' num2str(i)])
          imgdir = [impath '/' celldirlist{i}];
          downsample = [5 5 1];
          [nucbodyimg,cellbodyimg] = seg_cell_and_nucleus( imgdir, downsample, display, param );
%         crops = ml_dir([imgdir '/crop/*.tif']);
%         crop = ml_readimage([imgdir '/crop/' crops{1}]) > 0;
%         crop = crop(13:end-12,13:end-12);
%         crop = imresize(crop,0.2);
%         se = strel('disk',3);
%         
%         % Load and process dna image
%         img = ml_loadimage([imgdir '/dna'],'tif');
%         img = img(13:end-12,13:end-12,:);
%         img = tp_imresize3D(img,5,'downsampling');
%         stacknum = size(img,3);
%         img = double(img);
%         for k = 1:stacknum
%             [proc,mask,res] = ml_preprocess(img(:,:,k),crop,'ml','yesbgsub');
%             if isempty(mask)
%                 mask = false(size(img,1),size(img,2));
%             else
%                 mask = imclose(mask,se);
%                 mask = tp_findmainregion(mask);
%                 mask = imfill(mask,'holes');
%             end
%             nucbodyimg(:,:,k) = mask;
%         end
        
        % Load and process cell image
%         img = ml_loadimage([imgdir '/cell'],'tif');
%         img = img(13:end-12,13:end-12,:);
%         img = tp_imresize3D(img,5,'downsampling');
%         stacknum = size(img,3);
%         img = double(img);
%         for k = 1:stacknum
%             [proc,mask,res] = ml_preprocess(img(:,:,k),crop,'ml','yesbgsub');
%             if isempty(mask)
%                 mask = false(size(img,1),size(img,2));
%             else
%                 mask = imclose(mask,se);
%                 mask = tp_findmainregion(mask);
%                 mask = imfill(mask,'holes');
%             end
%             cellbodyimg(:,:,k) = mask;
%         end
        
        nucEdge = bwperim(nucbodyimg,18);
        cellEdge = bwperim(cellbodyimg,18);
        
        % Load object centres
        load([gaussobjpath '_gaussobjs.mat'])
        objcentres = zeros(size(cellEdge));
        mix = mixes{i};
        offset = offsets{i};
        for p = 1:length(mix)
            for t = 1:mix(p).ncentres
                ecof = mix(p).centres(t,:) + offset(p,:);
                ecof = round([ecof(1:2)/5,ecof(3)]);
                ecof(ecof==0) = 1;
                ecof(ecof>=200) = 200;
                objcentres(ecof(1),ecof(2),ecof(3)) = 1;
            end
        end
        objcentres(~cellbodyimg) = 0;
        
        % Train position model
        [distcodes,coords,angles] = ...
            ml_celldistcode(cellEdge,nucEdge,objcentres,1,'all');
        nullidx = find(distcodes(:,1)==0 & distcodes(:,2)==0);
        distcodes(nullidx,:)=[];
        %     coords(nullidx,:)=[];
        angles.theta(nullidx,:)=[];
        angles.phi(nullidx,:)=[];
        normdists = distcodes(:,1)./sum(abs(distcodes(:,1:2)),2);
        x = ml_mappos([normdists angles.theta angles.phi]);
        X = [X;x];
        Y = [Y;distcodes(:,3)];
        imageID = [imageID;repmat(i,size(x,1),1)];
        BETA(i,:) = ml_logreg(x,distcodes(:,3))';
        save([savepath '_Beta.mat'],'BETA')
    end
    
    BETA = ml_logreg(X,Y)';
    save([savepath filesep protype '_beta_all.mat'],'BETA','X','Y','imageID')
else
    load( [savepath filesep protype '_beta_all.mat'] );
end

% qarray -m "objpos_run('Mit');"
% qarray -m "objpos_run('LAM');"
% qarray -m "objpos_run('Nuc');"
% qarray -m "objpos_run('TfR');"
