function [nucimg,nucsurf2] = tp_gennucshape(instance,param)
% TP_GENNUCSHAPE generates a nuclear shape from the tensor-product spline
% surface structure

if nargin < 1
    error('1 or 2 arguments are required');
end

if ~exist('param','var')
    param = struct([]);
end

f = 5;
MEAN_HEIGHT = 85;

instance.coefs = shiftdim(instance.coefs,-1);
H = f*instance.height;

param = ml_initparam(param,...
    struct('xsize',1024,'ysize',1024,'zsize',H+1,'samp_rate',360));

xcenter = param.xsize / 2;
ycenter = param.ysize / 2;

delta = 2*pi/param.samp_rate;
Phi = -pi:delta:pi;
Z = 0:(1/H):1;

[Phi_grid, Z_grid] = meshgrid(Phi,Z);
mesh_data = [Z_grid(:), Phi_grid(:)]';
nucsurf = f * reshape(fnval(instance,mesh_data),[length(Z),length(Phi)]);
nucsurf = nucsurf/2;

Z = 0:(1/MEAN_HEIGHT):1;
[Phi_grid, Z_grid] = meshgrid(Phi,Z);
mesh_data = [Z_grid(:), Phi_grid(:)]';
nucsurf2 = f * reshape(fnval(instance,mesh_data),[length(Z),length(Phi)]);
nucsurf2 = nucsurf2/2;

nucimg = uint8(zeros(param.ysize,param.xsize,param.zsize));
for i = 1:(H+1)
    [x,y] = pol2cart(Phi,nucsurf(i,:));
    x = x + xcenter;
    y = y + ycenter;
    sliceimg = zeros(param.ysize,param.xsize);
    for t = 1:length(x)-1
        rpts = round(linspace(y(t),y(t+1),100));
        cpts = round(linspace(x(t),x(t+1),100));
        index = sub2ind([param.ysize,param.xsize],rpts,cpts);
        sliceimg(index) = 255;
    end
    nucimg(:,:,i) = imfill(sliceimg,'holes');
end

%blankimg = zeros(param.ysize,param.xsize);
%nucimg = cat(3,blankimg,nucimg,blankimg);
