function [distcodes,coords,angles] = ...
    ml_celldistcode2(param,loc)
%ML_CELLDISTCODE Coding pixels by their distaces to cell and nuclues edge.
%   DISTCODES = ML_CELLDISTCODE(param.cell,param.nucleus,OBJECTS,ISBIN) returs a
%   3-column matrix DISTCODES. Each row of DISTCODES has the form
%   [[nucleus distance,cell distance,gray level]. param.cell and param.nucleus are
%   [image]s for cell edge and nuclues edge. 
%   
%   ML_CELLDISTCODE(param.cell,param.nucleus,OBJECTS,ISBIN,LOC) specifies what
%   regions are coded:
%       'cyt' - cytoplasm
%       'nuc' - nucleus
%       'all' - whole cell
%
%   [DISTCODES,COORDS,ANGLES] = ML_CELLDISTCODE(...) also returns the 
%   coordinates.
% Copyright (C) 2007  Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu
%   param.cell - non-filled cell image
%   param.nuclear - non-filled nuc image 
%   param.cellfilled - 
%   param.nuclearfilled - 

% March 19, 2012 R.F. Murphy and Devin Sullivan Created from
% ml_celldistcode.m by T. Zhao
%   Copyright (c) Murphy Lab, Carnegie Mellon University

try
   verbose = param.verbose;
catch
   verbose = true;
end

if ~exist('loc','var')
    loc = 'cyt';
end

%if verbose
%   disp( 'Loading cell edge image' );
%end

%data = load( param.cellmatfile );
%param.cell = data.param.cell;

%if verbose
%disp( 'Loading nuclear edge' );
%end

%data = load( param.nucleusmatfile );
%param.nucleus = data.param.nucleus;

%clear data;

if any(size(param.cell)~=size(param.nucleus))
    error('sizes of edge images do not match');
end

switch loc
    case 'cyt'
        codemask = double(param.cellfilled)-double(param.nucleusfilled);
    case 'nuc'
        codemask = double(param.nucleusfilled - bwperim(param.nucleusfilled));
%         codemask = double(param.cellfilled)-double(param.cellfilled);
    case 'all'
        codemask = double(param.cellfilled- bwperim(param.cellfilled));
    otherwise
        error(['unrecognized location name: ' loc]);
end
%if verbose
%disp( 'Calculating distances' );
%end
ind = find(codemask==1);
[X,Y,Z] = ind2sub(size(codemask),ind);
coords = [X,Y,Z];

distcodes = [param.nucleardist(ind),param.celldist(ind),param.cellfilled(ind)];

%data = load( param.nucleusmatfile );
%param.nucleus = data.param.nucleus;
%clear data

%Calculate angles
%if verbose
%   disp( 'Calculating angles' );
%end
if nargout==3
    [center,mangle] = ml_objcenter(param.nucleusfilled);
%     pt1 = center+[cos(mangle),sin(mangle)];
%     pt2 = center;
    [th,phi,r] = cart2sph(coords(:,1)-center(1),coords(:,2)-center(2),...
        coords(:,3)-center(3));
    th = th - mangle;
    angles.theta = th;
    angles.phi = phi;
%     angles = ml_normangle(ml_normangle( ...
%         ml_normangle(th,'r2a'),'360'),'a2r');
    
    %Old algorithm (slow)
    %for i=1:size(coords,1)
    %    angles2(i) = tz_findangle_2d(pt1,pt2,coords(i,:));
    %end
    %sum(abs(angles-angles2'))
end