function [nucimg, cellimg] = model2framework( model, param )

% Author: Ivan E. Cao-Berg (icaoberg@scs.cmu.edu)
%
% Copyright (C) 2012 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

% April 7, 2012 R.F. Murphy Use modified function for synthesizing cell
% shape; adding additional models for height ratios and nuclear position

if nargin > 3
  error('CellOrganizer: Wrong number of input arguments.' );
end

if length(model) > 1
  model = model{1};
end

if ~exist( 'param', 'var' )
 param = [];
end

try
  dimensionality = model.dimensionality;
catch
  error( 'CellOrganizer: Unable to set dimensionality' );
end

switch lower(dimensionality)
  case '2d'
      param = ml_initparam(param, ...
            struct('imageSize',[1024 1024],'gentex',0,'loc','all'));

       %generate cell framework
       [nucimg,cellimg] = ml_gencellcomp2D( model, param );
  case '3d'
        instance = tp_genspsurf(model.nuclearShapeModel);
        [nucimg,nucsurf] = tp_gennucshape(instance);

        nucleus.nucimgsize = size(nucimg);
        nucleus.nucsurf = nucsurf;
        nucleus.nucimg = nucimg;
        [cellimg,nucimg] = ml_gencellshape3d(model.cellShapeModel,nucleus,param);
        box = tp_imbox(cellimg);
        nucimg = nucimg(box(1):box(2),box(3):box(4),:);
        cellimg = cellimg(box(1):box(2),box(3):box(4),:);
  otherwise
        return
end
