function seg = activcon_seg(image,startingmask,display)
%ACTIVCON_SEG Region Based Active Contours

% Original Author: Shawn Lankton
% 
% Copyright (C) 2012 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% Modified March 15, 2012 R.F. Murphy Use bounding box to speed up calcs
% Modified March 21, 2012 R.F. Murphy Add display argument
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

I =uint16(image);
seg = zeros(size(I,1),size(I,2));
[X,Y]=find(I>0);
border = 10;
% find bounding box but leave some black space around it if possible
Xbox = [max(1,min(X)-border):min(size(I,1),max(X)+border)];
Ybox = [max(1,min(Y)-border):min(size(I,2),max(Y)+border)];

if length(Xbox)<2*border | length(Ybox)<2*border
    return
end
if ~exist('startingmask','var') | isempty(startingmask) | max(max(startingmask))==0
    startingmask = zeros(size(I,1),size(I,2));          %-- create initial mask
% make sure that the starting mask is inside the image
    startingmask(Xbox(border):Xbox(end-border),Ybox(border):Ybox(end-border)) = 1;
end
seg(Xbox,Ybox) = region_seg(I(Xbox,Ybox), startingmask(Xbox,Ybox), 1000, 0.2, display, 0); %-- Run segmentation
