function [segimage,phis3D] = active3Dsegment(image,startsliceno,stopsliceno,display)
%ACTIVE3DSEGMENT Active Contour 3D Segmentation

% Author: Aabid Shariff
%
% Copyright (C) 2012 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% March 15, 2012 R.F. Murphy Start with previous mask to speedup
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

% March 21, 2012 R.F. Murphy Add display param; remove disconnected pieces


segimage = false(size(image));
mask = [];

% decide which order to process slices in - better to start with biggest
[X1,Y1]=find(image(:,:,startsliceno));
[X2,Y2]=find(image(:,:,stopsliceno));
areabox1 = (max(X1)-min(X1)+1)*(max(Y1)-min(Y1)+1);
areabox2 = (max(X2)-min(X2)+1)*(max(Y2)-min(Y2)+1);
sliceinc = 1; % assume start -> stop
if areabox2 > areabox1
    tmp = startsliceno;
    startsliceno = stopsliceno;
    stopsliceno = tmp;
    sliceinc = -1; % reverse direction
end

% use the mask from previous slice as the estimated mask for next slice
for I = startsliceno:sliceinc:stopsliceno
    mask = activcon_seg(image(:,:,I),mask,display);
    % pick the biggest object (clear the others)
    cc=bwconncomp(mask);
    if cc.NumObjects>1
        numPixels = cellfun(@numel,cc.PixelIdxList);
        [~,bigind] = max(numPixels);
        for i=1:cc.NumObjects
            if i~=bigind
                mask(cc.PixelIdxList{i})=0;
            end
        end
    end
    segimage(:,:,I)=mask;
end
