function model = train_protein_model(imgdir)
% Train objectized protein and position model using 3D HeLa GFP images

% Author: Tao Peng
% Edited: Ivan E. Cao-Berg
%
% Copyright (C) 2011 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

temporaryFilesFolder = [ pwd filesep 'temp' filesep 'protein_objects_gaussian' ];
if ~exist( temporaryFilesFolder, 'dir' )
    mkdir( temporaryFilesFolder );
end

% Extract protein objects from 4 image sets (note this step can be parallelized)
savedir = [ temporaryFilesFolder filesep 'original_objects'];
if ~exist( savedir, 'dir' )
    mkdir( savedir );
end

disp( 'Finding objects in images...' );
findobjs_run( imgdir, savedir );

disp( 'Fitting Gaussian mixtures to the objects...' );
savedir = './temp/protein_objects_gaussian/object_gaussians';
if ~exist(savedir,'dir')
    mkdir(savedir)
end
 
learngaussobjs_run2(imgdir,savedir);

disp( 'Learning object models...' );
gaussianobjdir = './temp/protein_objects_gaussian/object_gaussians';
savedir = './temp/protein_objects_gaussian/object_stats';
gmm_objempdistr(gaussianobjdir,savedir);
for p = 1:length(patternlist)
     models(p).size = gmm_objsizefit(patternlist{p},savedir);
end
 
disp( 'Learning object position models...' );
 savedir = './inter_results/protein_objects_gaussian/object_positions';
 if ~exist(savedir,'dir')
     mkdir(savedir)
 end
 
 for p = 1:length(patternlist)
     models(p).position.beta = objpos_run(patternlist{p},imgdir,savedir);
 end
 
 % Save protein models
 disp( 'Saving protein models' );
 savedir = './inter_results/protein_objects_gaussian';
 for p = 1:length(patternlist)
     model = models(p);
     save([savedir '/' patternlist{p} '_model'],'model');
 end
